==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/SymbolicConstantValueSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.constants.SymbolicConstantSet;
import io.ciera.tool.sql.ooaofooa.constants.impl.SymbolicConstantSetImpl;
import io.ciera.tool.sql.ooaofooa.value.SymbolicConstantValue;
import io.ciera.tool.sql.ooaofooa.value.SymbolicConstantValueSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.List;


public class SymbolicConstantValueSetImpl extends InstanceSet<SymbolicConstantValueSet,SymbolicConstantValue> implements SymbolicConstantValueSet {

    // attributes
    @Override
    public void setDT_ID_Deprecated( UniqueId m_DT_ID_Deprecated ) throws XtumlException {
        for ( SymbolicConstantValue symbolicconstantvalue : this ) symbolicconstantvalue.setDT_ID_Deprecated( m_DT_ID_Deprecated );
    }
    @Override
    public void setConst_ID( UniqueId ref_Const_ID ) throws XtumlException {
        for ( SymbolicConstantValue symbolicconstantvalue : this ) symbolicconstantvalue.setConst_ID( ref_Const_ID );
    }
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( SymbolicConstantValue symbolicconstantvalue : this ) symbolicconstantvalue.setValue_ID( ref_Value_ID );
    }


    // selections
    @Override
    public ValueSet R801_is_a_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( SymbolicConstantValue symbolicconstantvalue : this ) valueset.add( symbolicconstantvalue.R801_is_a_Value() );
        return valueset;
    }
    @Override
    public SymbolicConstantSet R850_SymbolicConstant() throws XtumlException {
        SymbolicConstantSet symbolicconstantset = new SymbolicConstantSetImpl();
        for ( SymbolicConstantValue symbolicconstantvalue : this ) symbolicconstantset.add( symbolicconstantvalue.R850_SymbolicConstant() );
        return symbolicconstantset;
    }


    @Override
    public SymbolicConstantValue nullElement() {
        return SymbolicConstantValueImpl.EMPTY_SYMBOLICCONSTANTVALUE;
    }

    @Override
    public SymbolicConstantValueSet emptySet() {
      return new SymbolicConstantValueSetImpl();
    }

    @Override
    public SymbolicConstantValueSet value() {
        return this;
    }

    @Override
    public List<SymbolicConstantValue> elements() {
        return Arrays.asList(toArray(new SymbolicConstantValue[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/SymbolicConstantValueSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.constants.SymbolicConstantSet;
import io.ciera.tool.sql.ooaofooa.constants.impl.SymbolicConstantSetImpl;
import io.ciera.tool.sql.ooaofooa.value.SymbolicConstantValue;
import io.ciera.tool.sql.ooaofooa.value.SymbolicConstantValueSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class SymbolicConstantValueSetImpl extends InstanceSet<SymbolicConstantValueSet,SymbolicConstantValue> implements SymbolicConstantValueSet {

    public SymbolicConstantValueSetImpl() {
    }

    public SymbolicConstantValueSetImpl(Comparator<? super SymbolicConstantValue> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setDT_ID_Deprecated( UniqueId m_DT_ID_Deprecated ) throws XtumlException {
        for ( SymbolicConstantValue symbolicconstantvalue : this ) symbolicconstantvalue.setDT_ID_Deprecated( m_DT_ID_Deprecated );
    }
    @Override
    public void setConst_ID( UniqueId ref_Const_ID ) throws XtumlException {
        for ( SymbolicConstantValue symbolicconstantvalue : this ) symbolicconstantvalue.setConst_ID( ref_Const_ID );
    }
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( SymbolicConstantValue symbolicconstantvalue : this ) symbolicconstantvalue.setValue_ID( ref_Value_ID );
    }


    // selections
    @Override
    public ValueSet R801_is_a_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( SymbolicConstantValue symbolicconstantvalue : this ) valueset.add( symbolicconstantvalue.R801_is_a_Value() );
        return valueset;
    }
    @Override
    public SymbolicConstantSet R850_SymbolicConstant() throws XtumlException {
        SymbolicConstantSet symbolicconstantset = new SymbolicConstantSetImpl();
        for ( SymbolicConstantValue symbolicconstantvalue : this ) symbolicconstantset.add( symbolicconstantvalue.R850_SymbolicConstant() );
        return symbolicconstantset;
    }


    @Override
    public SymbolicConstantValue nullElement() {
        return SymbolicConstantValueImpl.EMPTY_SYMBOLICCONSTANTVALUE;
    }

    @Override
    public SymbolicConstantValueSet emptySet() {
      return new SymbolicConstantValueSetImpl();
    }

    @Override
    public SymbolicConstantValueSet emptySet(Comparator<? super SymbolicConstantValue> comp) {
      return new SymbolicConstantValueSetImpl(comp);
    }

    @Override
    public SymbolicConstantValueSet value() {
        return this;
    }

    @Override
    public List<SymbolicConstantValue> elements() {
        return Arrays.asList(toArray(new SymbolicConstantValue[0]));
    }

}
